<?php

namespace Laraecart\Cart\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Laraecart\Cart\Interfaces\AddressRepositoryInterface;

class AddressPublicController extends BaseController
{
    // use AddressWorkflow;

    /**
     * Constructor.
     *
     * @param type \Laraecart\Address\Interfaces\AddressRepositoryInterface $address
     *
     * @return type
     */
    public function __construct(AddressRepositoryInterface $address)
    {
        $this->repository = $address;
        parent::__construct();
    }

    /**
     * Show address's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $addresses = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$cart::address.names'))
            ->view('cart::address.index')
            ->data(compact('addresses'))
            ->output();
    }


    /**
     * Show address.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $address = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$address->name . trans('cart::address.name'))
            ->view('cart::address.show')
            ->data(compact('address'))
            ->output();
    }

}
